pub struct Field {
pub name: String,
pub class: Vec<String>,
pub _type: Option<String>,
pub value: Option<String>,
pub title: Option<String>,
}Fields
name: StringA name describing the control. Field names MUST be unique within the set of fields for an action. The behaviour of clients when parsing a Siren document that violates this constraint is undefined. Required.
class: Vec<String>Describes aspects of the field based on the current representation. Possible values are implementation-dependent and should be documented. MUST be an array of strings. Optional.
_type: Option<String>The input type of the field. This may include any of the following input types specified in HTML5: hidden, text, search, tel, url, email, password, datetime, date, month, week, time, datetime-local, number, range, color, checkbox, radio, file When missing, the default value is text. Serialization of these fields will depend on the value of the action’s type attribute. See type under Actions, above. Optional.
value: Option<String>A value assigned to the field. Optional.
title: Option<String>Textual annotation of a field. Clients may use this as a label. Optional.